export interface Automation extends AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the automation is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the automation.
     *
     * Ignored when creating an automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Information about the creator of the automation.
     * @immutable
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * Date and time the automation was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The entity that last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * Date and time the automation was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Automation name that is displayed on the user's site.
     * @minLength 1
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description.
     * @maxLength 2000
     */
    description?: string | null;
    /** Object that defines the automation's trigger, actions, and activation status. */
    configuration?: AutomationConfiguration;
    /**
     * Defines how the automation was added to the site.
     * @immutable
     */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * Draft info (optional - only if the automation is a draft)
     * @readonly
     */
    draftInfo?: DraftInfo;
    /**
     * Namespace
     * @maxLength 50
     */
    namespace?: string | null;
    /** Extended Fields */
    extendedFields?: ExtendedFields;
}
/** @oneof */
export interface AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
}
export interface ActionSettings {
    /**
     * List of actions that cannot be deleted.
     * Default: Empty. All actions are deletable by default.
     * @maxSize 30
     * @format GUID
     */
    permanentActionIds?: string[];
    /**
     * List of actions that cannot be edited.
     * Default: Empty. All actions are editable by default.
     * @maxSize 30
     * @format GUID
     */
    readonlyActionIds?: string[];
    /** Whether the option to add a delay is disabled for the automation. */
    disableDelayAddition?: boolean;
    /** Whether the option to add a condition is disabled for the automation. */
    disableConditionAddition?: boolean;
}
export declare enum Domain {
    /** User domain (default). */
    USER = "USER",
    /** Wix domain. */
    WIX = "WIX"
}
export interface Enrichment {
    /**
     * Enrichment input mappings.
     * @maxSize 2
     */
    inputMappings?: Record<string, any>[] | null;
}
export interface AuditInfo extends AuditInfoIdOneOf {
    /**
     * User ID.
     * @format GUID
     */
    userId?: string;
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
}
/** @oneof */
export interface AuditInfoIdOneOf {
    /**
     * User ID.
     * @format GUID
     */
    userId?: string;
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
}
/** Automation runtime configuration */
export interface AutomationConfiguration {
    /** Status of the automation on the site. */
    status?: Status;
    /** Automation trigger configuration. */
    trigger?: Trigger;
    /**
     * List of IDs of root actions. Root actions are the first actions to run after the trigger. The actions in the list run in parallel.
     * @maxSize 20
     * @format GUID
     */
    rootActionIds?: string[];
    /**
     * Map of all actions that the automation may execute.
     * The key is the action ID, and the value is the action configuration.
     */
    actions?: Record<string, Action>;
}
export declare enum TimeUnit {
    UNKNOWN_TIME_UNIT = "UNKNOWN_TIME_UNIT",
    MINUTES = "MINUTES",
    HOURS = "HOURS",
    DAYS = "DAYS",
    WEEKS = "WEEKS",
    MONTHS = "MONTHS"
}
export interface Filter {
    /**
     * Filter ID.
     * @format GUID
     */
    _id?: string;
    /**
     * Field key from the payload schema, for example "formId".
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
    /**
     * Filter expression that evaluates to a boolean.
     * @maxLength 2500
     */
    filterExpression?: string;
}
export interface FutureDateActivationOffset {
    /**
     * The offset value. The value is always taken as negative, so that the automation runs before the trigger date.
     * To create an offset that causes the automation to run after the trigger date, use a delay action.
     * @maxLength 1000
     */
    preScheduledEventOffsetExpression?: string;
    /** Time unit for the scheduled event offset. */
    scheduledEventOffsetTimeUnit?: TimeUnit;
}
export interface RateLimit {
    /**
     * Value expressing the maximum number of times the trigger can be activated.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limiting window in the selected time unit. If no value is set, the rate limit is permanent.
     * @maxLength 1000
     */
    durationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    durationTimeUnit?: TimeUnit;
    /**
     * Unique identifier of each activation, by which rate limiter will count activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
}
export interface FilterValueSelection {
    /**
     * Values that can help the user filter certain automations, values will look like "<filter_id>__<selected_value>"
     * @maxLength 80
     * @maxSize 50
     */
    selectedFilterValues?: string[];
}
export interface ConditionExpressionGroup {
    /** Expression group operator. */
    operator?: Operator;
    /**
     * List of boolean expressions to be evaluated with the given operator.
     * @minSize 1
     * @maxSize 20
     * @maxLength 2500
     */
    booleanExpressions?: string[];
}
export declare enum Operator {
    UNKNOWN_OPERATOR = "UNKNOWN_OPERATOR",
    OR = "OR",
    AND = "AND"
}
export declare enum Type {
    /** Automation will be triggered according to the trigger configuration. */
    UNKNOWN_ACTION_TYPE = "UNKNOWN_ACTION_TYPE",
    /** App defined Action. */
    APP_DEFINED = "APP_DEFINED",
    /** Condition Action. */
    CONDITION = "CONDITION",
    /** Delay Action. */
    DELAY = "DELAY",
    /** RateLimit Action. */
    RATE_LIMIT = "RATE_LIMIT",
    /** Set Variables Action. */
    SET_VARIABLES = "SET_VARIABLES",
    /** Output Action. */
    OUTPUT = "OUTPUT"
}
export interface AppDefinedAction {
    /**
     * ID of the app that defines the action.
     * @format GUID
     */
    appId?: string;
    /**
     * Action key.
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
    /** Action input mapping. */
    inputMapping?: Record<string, any> | null;
    /**
     * Array of conditions determining whether to skip the action in the automation flow.
     * The action will be skipped if any of the expression groups evaluate to `true`.
     * Actions following a skipped action will still run.
     * @maxSize 10
     */
    skipConditionOrExpressionGroups?: ConditionExpressionGroup[];
    /**
     * List of IDs of actions to run in parallel once the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
    /** Optional output schema of the action. It will be used instead the action schema in case it's provided. */
    overrideOutputSchema?: Record<string, any> | null;
}
export interface ConditionAction {
    /**
     * The condition evaluates to `true` if either of the expression groups evaluate to `true`.
     * @minSize 1
     * @maxSize 10
     */
    orExpressionGroups?: ConditionExpressionGroup[];
    /**
     * List of IDs of actions to run when the entire condition is evaluated to `true`.
     * @maxSize 20
     * @format GUID
     */
    truePostActionIds?: string[];
    /**
     * List of IDs of actions to run when the entire condition is evaluated to `false`.
     * @maxSize 20
     * @format GUID
     */
    falsePostActionIds?: string[];
}
export interface DelayAction {
    /**
     * Value expressing the amount of time to wait from a specific date or from the time the action is executed.
     * @maxLength 1000
     */
    offsetExpression?: string | null;
    /** Time unit for delay offset. */
    offsetTimeUnit?: TimeUnit;
    /**
     * The action due date. If defined without an offset, the automation will wait until this date to execute the next step.
     * If an offset is defined, it's calculated from this date.
     * The date is expressed in the number of milliseconds since the Unix Epoch (1 January, 1970 UTC).
     * @maxLength 1000
     */
    dueDateEpochExpression?: string | null;
    /**
     * List of IDs of actions to run in parallel after the delay.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface RateLimitAction {
    /**
     * The maximum number of activations allowed for the action.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limiting window, expressed in selected time unit.
     * If no value is set, then there is no time limit on the rate limiter.
     * @maxLength 1000
     */
    rateLimitDurationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    rateLimitDurationTimeUnit?: TimeUnit;
    /**
     * Unique identifier of each activation by which rate limiter counts activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
    /**
     * List of IDs of actions to run in parallel once the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface SetVariablesAction {
    /**
     * output mapping
     * for example: {"someField": "{{10}}", "someOtherField": "{{multiply( var('account.points.balance') ;2 )}}" }
     */
    outputMapping?: Record<string, any> | null;
    /**
     * output json schema representation
     * could be string instead of Struct (and introduce some compression to minimize the size of it)
     */
    outputSchema?: Record<string, any> | null;
    /**
     * List of IDs of actions to run in parallel after variable initialization.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface OutputAction {
    /** Output action output mapping. */
    outputMapping?: Record<string, any> | null;
}
export declare enum Status {
    /** unused */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Automation will be triggered according to the trigger configuration */
    ACTIVE = "ACTIVE",
    /** Automation will not be triggered */
    INACTIVE = "INACTIVE"
}
export interface Trigger {
    /**
     * ID of the app that defines the trigger.
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * List of filters on schema fields.
     * In order for the automation to run, all filter expressions must evaluate to `true` for a given payload.
     * @maxSize 5
     */
    filters?: Filter[];
    /** Defines the time offset between the trigger date and when the automation runs. */
    scheduledEventOffset?: FutureDateActivationOffset;
    /** Limits the number of times an automation can be triggered. */
    rateLimit?: RateLimit;
    /**
     * An optional configuration, per automation, of a schema that is optionally offered by the trigger provider to affect the behavior of the trigger.
     * For example, a trigger provider may offer a schema that allows the user to configure the trigger to happen at a certain time of day,
     * He would define a schema with a field called "startDate" and using this parameter the user can define his preferred startDate, per automation.
     */
    automationConfigMapping?: Record<string, any> | null;
    /** Optional schema of the trigger. It will be used instead the trigger schema in case it's provided. */
    overrideSchema?: Record<string, any> | null;
}
export interface Action extends ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
    /**
     * Action ID. If not specified, a new ID is generated.
     * @format GUID
     */
    _id?: string | null;
    /** Action type. */
    type?: Type;
    /**
     * Human-readable name to differentiate the action from other actions of the same type.
     * The name can contain only alphanumeric characters and underscores. If not provided, a namespace in the form `actionkey-indexOfAction` is
     * generated automatically.
     * If the action has output, the output will be available in the payload under this name.
     * If the user has multiple actions with the same appId and actionKey, previous action output will be overwritten.
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
/** @oneof */
export interface ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
}
export interface FilterableAppDefinedActions {
    /**
     * App defined action identifiers, each identifier in form `${appId}_${actionKey}`
     * @minSize 1
     * @maxSize 100
     * @minLength 1
     * @maxLength 150
     */
    actionIdentifiers?: string[];
}
export declare enum Origin {
    /** Default value. This is unused. */
    UNKNOWN_ORIGIN = "UNKNOWN_ORIGIN",
    /** User created automation. */
    USER = "USER",
    /** Automation created by application (site specific). */
    APPLICATION = "APPLICATION",
    /** Preinstalled application automation. */
    PREINSTALLED = "PREINSTALLED",
    /** Automation created from a recipe. */
    RECIPE = "RECIPE"
}
export interface ApplicationOrigin {
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
    /**
     * External ID to correlate multiple sites to an automation
     * @format GUID
     */
    appDefinedExternalId?: string | null;
}
export interface PreinstalledOrigin {
    /**
     * ID of the app that defines the preinstalled automation.
     * @format GUID
     */
    appId?: string;
    /**
     * Application component ID.
     * @format GUID
     */
    componentId?: string;
    /** Application component version. */
    componentVersion?: number;
    /**
     * Whether the automation is an override automation. If the user modifies the preinstalled automation installed on their site, a site-specific
     * automation is created that overrides the original one. If the user makes no modifications this boolean is set to `false` and the original
     * preinstalled automation is used.
     *
     * Default: `false`
     * @immutable
     * @readonly
     */
    override?: boolean | null;
}
export interface AutomationSettings {
    /**
     * Whether the automation is hidden from users.
     * Default: `false`
     */
    hidden?: boolean;
    /**
     * Whether the automation is read-only.
     * Default: `false`
     */
    readonly?: boolean;
    /**
     * Whether the option to delete the automation from the site is disabled.
     * Default: `false`
     */
    disableDelete?: boolean;
    /**
     * Whether the option to change the automation status (from active to inactive and vice versa) is disabled.
     * Default: `false`
     */
    disableStatusChange?: boolean;
    /** Automation action settings. */
    actionSettings?: ActionSettings;
}
export interface DraftInfo {
    /**
     * Optional - automationId of the original automation.
     * @format GUID
     * @readonly
     */
    originalAutomationId?: string | null;
}
export interface Enrichments {
    /** Whether the studio site enrichment is wanted. */
    studioSite?: Enrichment;
}
export interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
export interface UpdatedWithPreviousEntity {
    /** previous automation */
    previousAutomation?: Automation;
    /** updated automation */
    currentAutomation?: Automation;
}
export interface DeletedWithEntity {
    /** Deleted automation */
    automation?: Automation;
}
export interface DraftPublished {
    /**
     * Draft automation ID
     * @format GUID
     */
    draftAutomationId?: string;
    /**
     * Draft original automation.
     * if it's not a draft of an existing automation, the draft original automation would be the draft itself
     */
    draftOriginalAutomation?: Automation;
    /** Updated automation after publishing the draft. */
    updatedAutomation?: Automation;
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface Empty {
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
export interface CreateAutomationRequest {
    /** Automation to be created. */
    automation: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export declare enum RequestedFields {
    UNKNOWN_REQUESTED_FIELD = "UNKNOWN_REQUESTED_FIELD",
    OVERRIDE_SCHEMA = "OVERRIDE_SCHEMA",
    FILTERABLE_EXTERNAL_VALUES = "FILTERABLE_EXTERNAL_VALUES",
    FILTERABLE_APP_DEFINED_ACTIONS = "FILTERABLE_APP_DEFINED_ACTIONS"
}
export interface CreateAutomationResponse {
    /** The created automation. */
    automation?: Automation;
}
export interface GetAutomationRequest {
    /**
     * Automation ID.
     * @format GUID
     */
    automationId: string;
    /** Automation origin. */
    origin?: Origin;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface GetAutomationResponse {
    /** The requested automation. */
    automation?: Automation;
}
export interface UpdateAutomationRequest {
    /** Automation to update. */
    automation: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface UpdateAutomationResponse {
    /** Updated automation. */
    automation?: Automation;
}
export interface DeleteAutomationRequest {
    /**
     * Automation ID.
     * @format GUID
     */
    automationId: string;
}
export interface DeleteAutomationResponse {
}
export interface BulkDeleteAutomationsRequest {
    /**
     * Automation IDs to delete.
     * @format GUID
     * @minSize 1
     * @maxSize 200
     */
    automationIds: string[];
}
export interface BulkDeleteAutomationsResponse {
    /**
     * Deleted automations results.
     * @minSize 1
     * @maxSize 200
     */
    results?: BulkDeleteResult[];
    /** Metadata for the API call. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkDeleteResult {
    /** Metadata for the item deletion. */
    itemMetadata?: ItemMetadata;
}
export interface ItemMetadata {
    /**
     * Item ID. Should always be available, unless it's impossible (for example, when failing to create an item).
     * @format GUID
     */
    _id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
export interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
export interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
export interface CreatePreinstalledAutomationRequest {
    /** Preinstalled automation to be created. */
    automation: Automation;
    /** Optional - hide the created automation behind a spec */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * Optional - the information about the original site automation that was used to create this preinstalled automation
     * Usually an existing automation in a site is used to create the preinstalled automation, this is the relevant information.
     */
    originAutomationInfo?: OriginAutomationInfo;
    /**
     * The app id for which the automation belongs
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface PreinstalledAutomationSpecInfo {
    /**
     * Spec to conduct on for the automation
     * @maxLength 128
     */
    spec?: string;
    /**
     * Value the spec should return in order to affect the user with the operation
     * e.g. creation - show the users the automation, update - show the users the updated automation, deletion - not show the users the automation
     * @maxLength 128
     */
    variantValue?: string | null;
    /**
     * Version from which the experiment should decide whether to expose it to users when !conduct(spec).contains(variant_value)
     * For example, if 50 is set, version 49 and below (including 49) will not expose the preinstalled automation to the user.
     */
    experimentVersion?: number;
}
export interface OriginAutomationInfo {
    /**
     * The original automation id
     * @format GUID
     */
    siteAutomationId?: string;
    /**
     * The original automation meta site id
     * @format GUID
     */
    metaSiteId?: string;
}
export interface CreatePreinstalledAutomationResponse {
    /** The created preinstalled automation. */
    automation?: Automation;
}
export interface UpdatePreinstalledAutomationRequest {
    /** Preinstalled automation to update. */
    automation: Automation;
    /** Optional - hide the updated automation behind a spec */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * The app id for which the automation belongs
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface UpdatePreinstalledAutomationResponse {
    /** Updated preinstalled automation. */
    automation?: Automation;
}
export interface DeletePreinstalledAutomationRequest {
    /**
     * Preinstalled Component Id
     * @format GUID
     */
    componentId: string;
    /**
     * Optional - makes the deletion operation gradual
     * The automation will not return if the variant returns for the site
     */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * The app id for which the component of the preinstalled belongs
     * @format GUID
     */
    appId?: string;
}
export interface DeletePreinstalledAutomationResponse {
}
export interface GeneratePreinstalledAutomationRequest {
    /** Automation */
    automation?: Automation;
    /**
     * The app id for which the automation belongs
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface GeneratePreinstalledAutomationResponse {
    /** Automation */
    automation?: Automation;
}
export interface QueryPreinstalledAutomationsForAppRequest {
    /** WQL expression. */
    query?: CursorQuery;
    /**
     * The app id which the query is requested for
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
export interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
export interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrder;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
export interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 500
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 64000
     */
    cursor?: string | null;
}
export interface QueryPreinstalledAutomationsForAppResponse {
    /** List of automations. */
    automations?: Automation[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
export interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
export interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 64000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 64000
     */
    prev?: string | null;
}
export interface QueryAutomationsRequest {
    /** WQL expression. */
    query?: CursorQuery;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface QueryAutomationsResponse {
    /** List of automations. */
    automations?: Automation[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
export interface GetAggregatedUsageInfoRequest {
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`
     */
    filter?: Record<string, any> | null;
}
export interface GetAggregatedUsageInfoResponse {
    /** Triggers in use */
    triggersUsageSummary?: TriggerUsageSummary[];
    /** Actions in use */
    actionsUsageSummary?: ActionUsageSummary[];
}
export interface TriggerUsageSummary {
    /**
     * ID of the app that defines the trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /** number of automations in which this trigger appears */
    automationsCount?: number;
}
export interface ActionUsageSummary {
    /**
     * ID of the app that defines the action
     * @format GUID
     */
    appId?: string;
    /**
     * Action key
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
    /** number of automations in which this action appears */
    automationsCount?: number;
}
export interface CopyAutomationRequest {
    /**
     * Automation ID.
     * @format GUID
     */
    automationId: string;
    /** Automation origin. */
    origin?: Origin;
    /** (optional) Automation to copy, skips fetch by id. */
    automation?: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface CopyAutomationResponse {
    /** Automation copy. */
    automation?: Automation;
}
export interface MetaSiteSpecialEvent extends MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
    /**
     * A meta site id.
     * @format GUID
     */
    metaSiteId?: string;
    /** A meta site version. Monotonically increasing. */
    version?: string;
    /** A timestamp of the event. */
    timestamp?: string;
    /**
     * TODO(meta-site): Change validation once validations are disabled for consumers
     * More context: https://wix.slack.com/archives/C0UHEBPFT/p1720957844413149 and https://wix.slack.com/archives/CFWKX325T/p1728892152855659
     * @maxSize 4000
     */
    assets?: Asset[];
}
/** @oneof */
export interface MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /**
     * Emitted when one of the URLs is changed. After this event you may call `urls-server` to fetch
     * the actual URL.
     *
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1732520791210559?thread_ts=1732027914.294059&cid=C0UHEBPFT
     * See: https://wix.slack.com/archives/C0UHEBPFT/p1744115197619459
     */
    urlChanged?: SiteUrlChanged;
}
export interface Asset {
    /**
     * An application definition id (app_id in dev-center). For legacy reasons may be UUID or a string (from Java Enum).
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * An instance id. For legacy reasons may be UUID or a string.
     * @maxLength 200
     */
    instanceId?: string;
    /** An application state. */
    state?: State;
}
export declare enum State {
    UNKNOWN = "UNKNOWN",
    ENABLED = "ENABLED",
    DISABLED = "DISABLED",
    PENDING = "PENDING",
    DEMO = "DEMO"
}
export interface SiteCreated {
    /**
     * A template identifier (empty if not created from a template).
     * @maxLength 36
     */
    originTemplateId?: string;
    /**
     * An account id of the owner.
     * @format GUID
     */
    ownerId?: string;
    /** A context in which meta site was created. */
    context?: SiteCreatedContext;
    /**
     * A meta site id from which this site was created.
     *
     * In case of a creation from a template it's a template id.
     * In case of a site duplication ("Save As" in dashboard or duplicate in UM) it's an id of a source site.
     * @format GUID
     */
    originMetaSiteId?: string | null;
    /**
     * A meta site name (URL slug).
     * @maxLength 20
     */
    siteName?: string;
    /** A namespace. */
    namespace?: Namespace;
}
export declare enum SiteCreatedContext {
    /** A valid option, we don't expose all reasons why site might be created. */
    OTHER = "OTHER",
    /** A meta site was created from template. */
    FROM_TEMPLATE = "FROM_TEMPLATE",
    /** A meta site was created by copying of the transfferred meta site. */
    DUPLICATE_BY_SITE_TRANSFER = "DUPLICATE_BY_SITE_TRANSFER",
    /** A copy of existing meta site. */
    DUPLICATE = "DUPLICATE",
    /** A meta site was created as a transfferred site (copy of the original), old flow, should die soon. */
    OLD_SITE_TRANSFER = "OLD_SITE_TRANSFER",
    /** deprecated A meta site was created for Flash editor. */
    FLASH = "FLASH"
}
export declare enum Namespace {
    UNKNOWN_NAMESPACE = "UNKNOWN_NAMESPACE",
    /** Default namespace for UGC sites. MetaSites with this namespace will be shown in a user's site list by default. */
    WIX = "WIX",
    /** ShoutOut stand alone product. These are siteless (no actual Wix site, no HtmlWeb). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    SHOUT_OUT = "SHOUT_OUT",
    /** MetaSites created by the Albums product, they appear as part of the Albums app. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ALBUMS = "ALBUMS",
    /** Part of the WixStores migration flow, a user tries to migrate and gets this site to view and if the user likes it then stores removes this namespace and deletes the old site with the old stores. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    WIX_STORES_TEST_DRIVE = "WIX_STORES_TEST_DRIVE",
    /** Hotels standalone (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    HOTELS = "HOTELS",
    /** Clubs siteless MetaSites, a club without a wix website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    CLUBS = "CLUBS",
    /** A partially created ADI website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ONBOARDING_DRAFT = "ONBOARDING_DRAFT",
    /** AppBuilder for AppStudio / shmite (c). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_SITE = "DEV_SITE",
    /** LogoMaker websites offered to the user after logo purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    LOGOS = "LOGOS",
    /** VideoMaker websites offered to the user after video purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    VIDEO_MAKER = "VIDEO_MAKER",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    PARTNER_DASHBOARD = "PARTNER_DASHBOARD",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_CENTER_COMPANY = "DEV_CENTER_COMPANY",
    /**
     * A draft created by HTML editor on open. Upon "first save" it will be moved to be of WIX domain.
     *
     * Meta site with this namespace will *not* be shown in a user's site list by default.
     */
    HTML_DRAFT = "HTML_DRAFT",
    /**
     * the user-journey for Fitness users who want to start from managing their business instead of designing their website.
     * Will be accessible from Site List and will not have a website app.
     * Once the user attaches a site, the site will become a regular wixsite.
     */
    SITELESS_BUSINESS = "SITELESS_BUSINESS",
    /** Belongs to "strategic products" company. Supports new product in the creator's economy space. */
    CREATOR_ECONOMY = "CREATOR_ECONOMY",
    /** It is to be used in the Business First efforts. */
    DASHBOARD_FIRST = "DASHBOARD_FIRST",
    /** Bookings business flow with no site. */
    ANYWHERE = "ANYWHERE",
    /** Namespace for Headless Backoffice with no editor */
    HEADLESS = "HEADLESS",
    /**
     * Namespace for master site that will exist in parent account that will be referenced by subaccounts
     * The site will be used for account level CSM feature for enterprise
     */
    ACCOUNT_MASTER_CMS = "ACCOUNT_MASTER_CMS",
    /** Rise.ai Siteless account management for Gift Cards and Store Credit. */
    RISE = "RISE",
    /**
     * As part of the branded app new funnel, users now can create a meta site that will be branded app first.
     * There's a blank site behind the scene but it's blank).
     * The Mobile company will be the owner of this namespace.
     */
    BRANDED_FIRST = "BRANDED_FIRST",
    /** Nownia.com Siteless account management for Ai Scheduling Assistant. */
    NOWNIA = "NOWNIA",
    /**
     * UGC Templates are templates that are created by users for personal use and to sale to other users.
     * The Partners company owns this namespace.
     */
    UGC_TEMPLATE = "UGC_TEMPLATE",
    /** Codux Headless Sites */
    CODUX = "CODUX",
    /** Bobb - AI Design Creator. */
    MEDIA_DESIGN_CREATOR = "MEDIA_DESIGN_CREATOR",
    /**
     * Shared Blog Site is a unique single site across Enterprise account,
     * This site will hold all Blog posts related to the Marketing product.
     */
    SHARED_BLOG_ENTERPRISE = "SHARED_BLOG_ENTERPRISE",
    /** Standalone forms (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_FORMS = "STANDALONE_FORMS",
    /** Standalone events (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    STANDALONE_EVENTS = "STANDALONE_EVENTS"
}
/** Site transferred to another user. */
export interface SiteTransferred {
    /**
     * A previous owner id (user that transfers meta site).
     * @format GUID
     */
    oldOwnerId?: string;
    /**
     * A new owner id (user that accepts meta site).
     * @format GUID
     */
    newOwnerId?: string;
}
/** Soft deletion of the meta site. Could be restored. */
export interface SiteDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
export interface DeleteContext {
    /** When the meta site was deleted. */
    dateDeleted?: Date | null;
    /** A status. */
    deleteStatus?: DeleteStatus;
    /**
     * A reason (flow).
     * @maxLength 255
     */
    deleteOrigin?: string;
    /**
     * A service that deleted it.
     * @maxLength 255
     */
    initiatorId?: string | null;
}
export declare enum DeleteStatus {
    UNKNOWN = "UNKNOWN",
    TRASH = "TRASH",
    DELETED = "DELETED",
    PENDING_PURGE = "PENDING_PURGE",
    PURGED_EXTERNALLY = "PURGED_EXTERNALLY"
}
/** Restoration of the meta site. */
export interface SiteUndeleted {
}
/** First publish of a meta site. Or subsequent publish after unpublish. */
export interface SitePublished {
}
export interface SiteUnpublished {
    /**
     * A list of URLs previously associated with the meta site.
     * @maxLength 4000
     * @maxSize 10000
     */
    urls?: string[];
}
export interface SiteMarkedAsTemplate {
}
export interface SiteMarkedAsWixSite {
}
/**
 * Represents a service provisioned a site.
 *
 * Note on `origin_instance_id`:
 * There is no guarantee that you will be able to find a meta site using `origin_instance_id`.
 * This is because of the following scenario:
 *
 * Imagine you have a template where a third-party application (TPA) includes some stub data,
 * such as a product catalog. When you create a site from this template, you inherit this
 * default product catalog. However, if the template's product catalog is modified,
 * your site will retain the catalog as it was at the time of site creation. This ensures that
 * your site remains consistent with what you initially received and does not include any
 * changes made to the original template afterward.
 * To ensure this, the TPA on the template gets a new instance_id.
 */
export interface ServiceProvisioned {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * An instance id from which this instance is originated.
     * @maxLength 36
     */
    originInstanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
    /**
     * The origin meta site id
     * @format GUID
     */
    originMetaSiteId?: string | null;
}
export interface ServiceRemoved {
    /**
     * Either UUID or EmbeddedServiceType.
     * @maxLength 36
     */
    appDefId?: string;
    /**
     * Not only UUID. Something here could be something weird.
     * @maxLength 36
     */
    instanceId?: string;
    /**
     * A version.
     * @maxLength 500
     */
    version?: string | null;
}
/** Rename of the site. Meaning, free public url has been changed as well. */
export interface SiteRenamed {
    /**
     * A new meta site name (URL slug).
     * @maxLength 20
     */
    newSiteName?: string;
    /**
     * A previous meta site name (URL slug).
     * @maxLength 255
     */
    oldSiteName?: string;
}
/**
 * Hard deletion of the meta site.
 *
 * Could not be restored. Therefore it's desirable to cleanup data.
 */
export interface SiteHardDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
export interface NamespaceChanged {
    /** A previous namespace. */
    oldNamespace?: Namespace;
    /** A new namespace. */
    newNamespace?: Namespace;
}
/** Assigned Studio editor */
export interface StudioAssigned {
}
/** Unassigned Studio editor */
export interface StudioUnassigned {
}
/**
 * Fired in case site URLs were changed in any way: new secondary domain, published, account slug rename, site rename etc.
 *
 * This is an internal event, it's not propagated in special events, because it's non-actionable. If you need to keep up
 * with sites and its urls, you need to listen to another topic/event. Read about it:
 *
 * https://bo.wix.com/wix-docs/rest/meta-site/meta-site---urls-service
 */
export interface SiteUrlChanged {
}
export interface CreateDraftAutomationRequest {
    /** Draft automation to be created. */
    automation?: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface CreateDraftAutomationResponse {
    /** The created draft automation. */
    automation?: Automation;
}
export interface GetOrCreateDraftAutomationRequest {
    /**
     * Original automation id
     * @format GUID
     */
    originalAutomationId: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface GetOrCreateDraftAutomationResponse {
    /** Draft automation. */
    automation?: Automation;
}
export interface UpdateDraftAutomationRequest {
    /** Automation to be updated, may be partial. */
    automation: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface UpdateDraftAutomationResponse {
    /** Updated draft automation. */
    automation?: Automation;
}
export interface QueryAutomationsWithDraftsRequest {
    /** WQL expression. */
    query?: CursorQuery;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface QueryAutomationsWithDraftsResponse {
    /** List of automations. */
    automations?: Automation[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
    /**
     * map of existing automationIds and their relevant drafts' automationIds
     * if include_draft_data: false was passed, the map will be empty
     * The key is the automationId of the original automation, and the value a list of related draft automationIds
     */
    originalAutomationIdToDrafts?: Record<string, DraftsInfo>;
}
export interface DraftsInfo {
    /**
     * list of drafts of an existing Automation
     * @maxSize 1
     * @format GUID
     */
    draftAutomationIds?: string[];
}
export interface DeleteDraftAutomationRequest {
    /**
     * Id of the draft automation to delete.
     * @format GUID
     */
    automationId: string;
}
export interface DeleteDraftAutomationResponse {
}
export interface PublishDraftAutomationRequest {
    /**
     * Id of the draft automation to publish.
     * @format GUID
     */
    automationId: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface PublishDraftAutomationResponse {
    /** Updated automation after publishing the draft */
    automation?: Automation;
}
export interface ValidateAutomationRequest {
    /** Automation to validate. */
    automation: Automation;
    /** Settings to customize the validation. */
    validationSettings?: ValidationSettings;
}
export interface ValidationSettings {
    /**
     * List of specific actions to validate. Only the actions in the list are validated. In this case, triggers are not validated.
     *
     * If the list is empty, the entire automation is validated, including triggers.
     *
     * Default: Empty.
     * @maxSize 30
     * @format GUID
     */
    actionIds?: string[];
    /**
     * Whether to skip provider validations.
     * Default: `false`
     */
    skipProviderValidations?: boolean;
}
export interface ValidateAutomationResponse {
    /** Whether the automation is valid. */
    valid?: boolean;
    /**
     * List of validation errors for the automation trigger.
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * List of validation information for the automation actions.
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
    /**
     * List of additional validation errors for the automation
     * @maxSize 100
     */
    automationValidationErrors?: AutomationValidationError[];
}
export interface TriggerValidationError extends TriggerValidationErrorErrorOneOf {
    /** Trigger configuration error. */
    configurationError?: TriggerConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
    /** Validation error type. */
    errorType?: TriggerValidationErrorValidationErrorType;
    /** Validation error severity */
    severity?: ValidationErrorSeverity;
}
/** @oneof */
export interface TriggerValidationErrorErrorOneOf {
    /** Trigger configuration error. */
    configurationError?: TriggerConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
}
export declare enum TriggerValidationErrorValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
export interface TriggerConfigurationError {
    /** Trigger error type. */
    errorType?: TriggerErrorType;
    /**
     * Related filter field key.
     * @maxLength 110
     */
    filterFieldKey?: string | null;
}
export declare enum TriggerErrorType {
    UNKNOWN_TRIGGER_ERROR_TYPE = "UNKNOWN_TRIGGER_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_TRIGGER_KEY = "INVALID_TRIGGER_KEY",
    INVALID_FILTER_FIELD_KEY = "INVALID_FILTER_FIELD_KEY",
    INVALID_FILTER_EXPRESSION = "INVALID_FILTER_EXPRESSION"
}
export interface ProviderConfigurationError {
    /** Key corresponding to the field in the schema. */
    fieldKey?: string | null;
    /** Error message. */
    message?: string;
    /** Label for a call-to-action button that's displayed with the error. Translated according to the SPI language context. */
    ctaLabel?: string | null;
    /** URL to redirect to when the call-to-action button is clicked. */
    ctaUrl?: string | null;
    /** Title for the error. */
    title?: string;
}
export declare enum ValidationErrorSeverity {
    UNKNOWN_VALIDATION_ERROR_SEVERITY = "UNKNOWN_VALIDATION_ERROR_SEVERITY",
    WARNING = "WARNING",
    ERROR = "ERROR"
}
export interface ActionValidationInfo {
    /**
     * Action ID.
     * @format GUID
     */
    actionId?: string | null;
    /**
     * ID of the app that defines the action.
     * @format GUID
     */
    appId?: string;
    /**
     * Human-readable action identifier.
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
    /**
     * List of action validation errors.
     * @maxSize 100
     */
    validationErrors?: ActionValidationError[];
}
export interface ActionValidationError extends ActionValidationErrorErrorOneOf {
    /** Action configuration error. */
    configurationError?: ActionConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
    /** Validation error type. */
    errorType?: ValidationErrorType;
    /** Validation error severity */
    severity?: ValidationErrorSeverity;
}
/** @oneof */
export interface ActionValidationErrorErrorOneOf {
    /** Action configuration error. */
    configurationError?: ActionConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
}
export declare enum ValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
export interface ActionConfigurationError {
    /** Action error type. */
    errorType?: ActionErrorType;
    /**
     * Related field key.
     * @maxLength 110
     */
    fieldKey?: string | null;
}
export declare enum ActionErrorType {
    UNKNOWN_ACTION_ERROR_TYPE = "UNKNOWN_ACTION_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_ACTION_KEY = "INVALID_ACTION_KEY",
    INVALID_MAPPING = "INVALID_MAPPING",
    MAPPING_TYPE_MISMATCH = "MAPPING_TYPE_MISMATCH",
    MAPPING_MISSING_REQUIRED_FIELD = "MAPPING_MISSING_REQUIRED_FIELD",
    MAPPING_SCHEMA_MISMATCH = "MAPPING_SCHEMA_MISMATCH",
    MAPPING_VARIABLE_MISSING_FROM_SCHEMA = "MAPPING_VARIABLE_MISSING_FROM_SCHEMA"
}
export interface AutomationValidationError extends AutomationValidationErrorErrorOneOf {
    /** Automation configuration error. */
    configurationError?: AutomationConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
    /** Validation error type. */
    errorType?: AutomationValidationErrorValidationErrorType;
    /** Validation error severity */
    severity?: ValidationErrorSeverity;
}
/** @oneof */
export interface AutomationValidationErrorErrorOneOf {
    /** Automation configuration error. */
    configurationError?: AutomationConfigurationError;
    /** Provider configuration error. */
    providerConfigurationError?: ProviderConfigurationError;
}
export declare enum AutomationValidationErrorValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
export interface AutomationConfigurationError {
    /** Automation error type. */
    errorType?: AutomationErrorType;
}
export declare enum AutomationErrorType {
    UNKNOWN_AUTOMATION_ERROR_TYPE = "UNKNOWN_AUTOMATION_ERROR_TYPE"
}
export interface ValidateAutomationByIdRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Settings to customize the validation. */
    validationSettings?: ValidationSettings;
}
export interface ValidateAutomationByIdResponse {
    /** Whether the automation is valid. */
    valid?: boolean;
    /**
     * List of validation errors for the automation trigger.
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * List of validation information for the automation actions.
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
    /**
     * List of additional validation errors for the automation
     * @maxSize 100
     */
    automationValidationErrors?: AutomationValidationError[];
}
export interface GetAutomationActionSchemaRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /**
     * Action ID
     * @format GUID
     */
    actionId: string;
}
export interface GetAutomationActionSchemaResponse {
    /** The accumulated payload schema for an action. */
    schema?: Record<string, any> | null;
}
export interface GetActionsQuotaInfoRequest {
}
export interface GetActionsQuotaInfoResponse {
    /** List of action quotas. */
    actionProviderQuotaInfo?: ActionProviderQuotaInfo[];
}
export interface ActionProviderQuotaInfo {
    /**
     * ID of the app that defines the action.
     * @format GUID
     */
    appId?: string;
    /**
     * Action key.
     * @minLength 1
     * @maxLength 80
     */
    actionKey?: string;
    /** Action quota information. */
    actionQuotaInfo?: ActionQuotaInfo;
}
export interface ActionQuotaInfo {
    /**
     * Whether the quotas for your action are enforced. If you mark this as `true` in the response body,
     * Wix displays the information in the quota object on the site dashboard. If you mark this as `false` for
     * a user, Wix does not display any quota info on the site dashboard for your service.
     */
    enforced?: boolean;
    /**
     * The plans your service provides, together with the quotas enforced by each plan. A site may be enrolled
     * in multiple plans. Plans and quotas can be related as follows:
     *
     * + A single plan has a single quota.
     * + A single plan has multiple quotas.
     * + Multiple plans are associated with multiple quotas.
     *
     * Plans and quotas that are related should be grouped together in a single `quotaInfo`
     * object.
     */
    quotaInfo?: QuotaInfo[];
}
export interface QuotaInfo {
    /** List of plans associated with the site making the request. */
    plans?: Plan[];
    /**
     * List of quotas associated with the plans the site is enrolled in.
     * @minSize 1
     */
    quotas?: Quota[];
    /**
     * Details for an upgrade call-to-action button.
     * Displayed in the Wix user’s site dashboard together with the quota details.
     */
    upgradeCta?: UpgradeCTA;
}
export interface Plan {
    /** Plan ID defined by the action provider. */
    _id?: string;
    /** Plan name to display in the Wix user’s site dashboard. */
    name?: string;
}
export interface Quota {
    /**
     * Name of the feature the quota is related to. For example, "Messages sent".
     * @minLength 1
     */
    featureName?: string;
    /**
     * Quota renewal date in [ISO 8601](https://www.iso.org/iso-8601-date-and-time-format.html) format.
     * For example, 10 July 2020 at 15:00 is written as `2020-07-10 15:00:00.000`.
     */
    renewalDate?: Date | null;
    /** The user's current quota usage. */
    currentUsage?: string;
    /** Quota limit data. */
    limit?: string | null;
    /** Additional information about the quota. Displayed as a tooltip in the Wix user’s dashboard. */
    additionalInfo?: AdditionalInfo;
}
export interface CTA {
    /**
     * Call-to-action redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * Call-to-action label.
     * @minLength 1
     */
    label?: string;
}
export interface AdditionalInfo {
    /**
     * Tooltip content.
     * @minLength 1
     */
    description?: string;
    /** Details for an options call-to-action link that appears in the tooltip. */
    cta?: CTA;
}
export interface UpgradeCTA {
    /**
     * CTA button redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * CTA button label.
     * @minLength 1
     */
    label?: string;
}
export interface MigrateVeloActionAutomationsRequest {
    /** @format GUID */
    oldAppId?: string;
    /** @format GUID */
    newAppId?: string;
    /** @format GUID */
    newComponentId?: string;
}
export interface MigrateVeloActionAutomationsResponse {
}
export interface GetAutomationRevisionRequest {
    /**
     * Automation ID.
     * @format GUID
     */
    automationId: string;
    /** Automation revision. */
    revision?: string | null;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export interface GetAutomationRevisionResponse {
    /** Automation with the relevant revision. */
    automation?: Automation;
}
interface ApplicationOriginNonNullableFields {
    appId: string;
}
interface PreinstalledOriginNonNullableFields {
    appId: string;
    componentId: string;
    componentVersion: number;
}
interface AuditInfoNonNullableFields {
    userId: string;
    appId: string;
}
interface FilterNonNullableFields {
    _id: string;
    fieldKey: string;
    filterExpression: string;
}
interface FutureDateActivationOffsetNonNullableFields {
    preScheduledEventOffsetExpression: string;
    scheduledEventOffsetTimeUnit: TimeUnit;
}
interface RateLimitNonNullableFields {
    maxActivationsExpression: string;
    durationTimeUnit: TimeUnit;
}
interface FilterValueSelectionNonNullableFields {
    selectedFilterValues: string[];
}
interface TriggerNonNullableFields {
    appId: string;
    triggerKey: string;
    filters: FilterNonNullableFields[];
    scheduledEventOffset?: FutureDateActivationOffsetNonNullableFields;
    rateLimit?: RateLimitNonNullableFields;
    filterValueSelection?: FilterValueSelectionNonNullableFields;
}
interface FilterableAppDefinedActionsNonNullableFields {
    actionIdentifiers: string[];
}
interface AutomationConfigurationNonNullableFields {
    status: Status;
    trigger?: TriggerNonNullableFields;
    rootActionIds: string[];
    filterableAppDefinedActions?: FilterableAppDefinedActionsNonNullableFields;
}
interface ActionSettingsNonNullableFields {
    permanentActionIds: string[];
    readonlyActionIds: string[];
    disableDelayAddition: boolean;
    disableConditionAddition: boolean;
}
interface AutomationSettingsNonNullableFields {
    hidden: boolean;
    readonly: boolean;
    disableDelete: boolean;
    disableStatusChange: boolean;
    actionSettings?: ActionSettingsNonNullableFields;
    domain: Domain;
}
export interface AutomationNonNullableFields {
    applicationInfo?: ApplicationOriginNonNullableFields;
    preinstalledInfo?: PreinstalledOriginNonNullableFields;
    createdBy?: AuditInfoNonNullableFields;
    updatedBy?: AuditInfoNonNullableFields;
    name: string;
    configuration?: AutomationConfigurationNonNullableFields;
    origin: Origin;
    settings?: AutomationSettingsNonNullableFields;
}
export interface CreateAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface GetAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface UpdateAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
interface ApplicationErrorNonNullableFields {
    code: string;
    description: string;
}
interface ItemMetadataNonNullableFields {
    originalIndex: number;
    success: boolean;
    error?: ApplicationErrorNonNullableFields;
}
interface BulkDeleteResultNonNullableFields {
    itemMetadata?: ItemMetadataNonNullableFields;
}
interface BulkActionMetadataNonNullableFields {
    totalSuccesses: number;
    totalFailures: number;
    undetailedFailures: number;
}
export interface BulkDeleteAutomationsResponseNonNullableFields {
    results: BulkDeleteResultNonNullableFields[];
    bulkActionMetadata?: BulkActionMetadataNonNullableFields;
}
export interface CreatePreinstalledAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface UpdatePreinstalledAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface QueryPreinstalledAutomationsForAppResponseNonNullableFields {
    automations: AutomationNonNullableFields[];
}
export interface QueryAutomationsResponseNonNullableFields {
    automations: AutomationNonNullableFields[];
}
export interface CopyAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface CreateDraftAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface GetOrCreateDraftAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface UpdateDraftAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface QueryAutomationsWithDraftsResponseNonNullableFields {
    automations: AutomationNonNullableFields[];
}
export interface PublishDraftAutomationResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
interface TriggerConfigurationErrorNonNullableFields {
    errorType: TriggerErrorType;
}
interface ProviderConfigurationErrorNonNullableFields {
    message: string;
    title: string;
}
interface TriggerValidationErrorNonNullableFields {
    configurationError?: TriggerConfigurationErrorNonNullableFields;
    providerConfigurationError?: ProviderConfigurationErrorNonNullableFields;
    errorType: TriggerValidationErrorValidationErrorType;
    severity: ValidationErrorSeverity;
}
interface ActionConfigurationErrorNonNullableFields {
    errorType: ActionErrorType;
}
interface ActionValidationErrorNonNullableFields {
    configurationError?: ActionConfigurationErrorNonNullableFields;
    providerConfigurationError?: ProviderConfigurationErrorNonNullableFields;
    errorType: ValidationErrorType;
    severity: ValidationErrorSeverity;
}
interface ActionValidationInfoNonNullableFields {
    appId: string;
    actionKey: string;
    validationErrors: ActionValidationErrorNonNullableFields[];
}
interface AutomationConfigurationErrorNonNullableFields {
    errorType: AutomationErrorType;
}
interface AutomationValidationErrorNonNullableFields {
    configurationError?: AutomationConfigurationErrorNonNullableFields;
    providerConfigurationError?: ProviderConfigurationErrorNonNullableFields;
    errorType: AutomationValidationErrorValidationErrorType;
    severity: ValidationErrorSeverity;
}
export interface ValidateAutomationResponseNonNullableFields {
    valid: boolean;
    triggerValidationErrors: TriggerValidationErrorNonNullableFields[];
    actionValidationInfo: ActionValidationInfoNonNullableFields[];
    automationValidationErrors: AutomationValidationErrorNonNullableFields[];
}
export interface ValidateAutomationByIdResponseNonNullableFields {
    valid: boolean;
    triggerValidationErrors: TriggerValidationErrorNonNullableFields[];
    actionValidationInfo: ActionValidationInfoNonNullableFields[];
    automationValidationErrors: AutomationValidationErrorNonNullableFields[];
}
interface PlanNonNullableFields {
    _id: string;
    name: string;
}
interface CTANonNullableFields {
    url: string;
    label: string;
}
interface AdditionalInfoNonNullableFields {
    description: string;
    cta?: CTANonNullableFields;
}
interface QuotaNonNullableFields {
    featureName: string;
    currentUsage: string;
    additionalInfo?: AdditionalInfoNonNullableFields;
}
interface UpgradeCTANonNullableFields {
    url: string;
    label: string;
}
interface QuotaInfoNonNullableFields {
    plans: PlanNonNullableFields[];
    quotas: QuotaNonNullableFields[];
    upgradeCta?: UpgradeCTANonNullableFields;
}
interface ActionQuotaInfoNonNullableFields {
    enforced: boolean;
    quotaInfo: QuotaInfoNonNullableFields[];
}
interface ActionProviderQuotaInfoNonNullableFields {
    appId: string;
    actionKey: string;
    actionQuotaInfo?: ActionQuotaInfoNonNullableFields;
}
export interface GetActionsQuotaInfoResponseNonNullableFields {
    actionProviderQuotaInfo: ActionProviderQuotaInfoNonNullableFields[];
}
export interface GetAutomationRevisionResponseNonNullableFields {
    automation?: AutomationNonNullableFields;
}
export interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
export interface EventMetadata extends BaseEventMetadata {
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
export interface AutomationCreatedEnvelope {
    entity: Automation;
    metadata: EventMetadata;
}
/** @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @webhook
 * @eventType wix.automations.v2.automation_created
 * @slug created
 * @documentationMaturity preview
 */
export declare function onAutomationCreated(handler: (event: AutomationCreatedEnvelope) => void | Promise<void>): void;
export interface AutomationDeletedEnvelope {
    entity: Automation;
    metadata: EventMetadata;
}
/** @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @webhook
 * @eventType wix.automations.v2.automation_deleted
 * @slug deleted
 * @documentationMaturity preview
 */
export declare function onAutomationDeleted(handler: (event: AutomationDeletedEnvelope) => void | Promise<void>): void;
export interface AutomationDeletedWithEntityEnvelope {
    data: DeletedWithEntity;
    metadata: EventMetadata;
}
/** @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @webhook
 * @eventType wix.automations.v2.automation_deleted_with_entity
 * @slug deleted_with_entity
 * @documentationMaturity preview
 */
export declare function onAutomationDeletedWithEntity(handler: (event: AutomationDeletedWithEntityEnvelope) => void | Promise<void>): void;
export interface AutomationUpdatedEnvelope {
    entity: Automation;
    metadata: EventMetadata;
}
/** @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @webhook
 * @eventType wix.automations.v2.automation_updated
 * @slug updated
 * @documentationMaturity preview
 */
export declare function onAutomationUpdated(handler: (event: AutomationUpdatedEnvelope) => void | Promise<void>): void;
export interface AutomationUpdatedWithPreviousEntityEnvelope {
    data: UpdatedWithPreviousEntity;
    metadata: EventMetadata;
}
/** @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @webhook
 * @eventType wix.automations.v2.automation_updated_with_previous_entity
 * @slug updated_with_previous_entity
 * @documentationMaturity preview
 */
export declare function onAutomationUpdatedWithPreviousEntity(handler: (event: AutomationUpdatedWithPreviousEntityEnvelope) => void | Promise<void>): void;
/**
 * Creates an automation.
 * @param automation - Automation to be created.
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @requiredField automation.configuration
 * @requiredField automation.configuration.actions
 * @requiredField automation.configuration.rootActionIds
 * @requiredField automation.configuration.status
 * @requiredField automation.configuration.trigger
 * @requiredField automation.configuration.trigger.appId
 * @requiredField automation.configuration.trigger.triggerKey
 * @requiredField automation.name
 * @requiredField automation.origin
 * @permissionId AUTOMATIONS.AUTOMATION_CREATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns The created automation.
 * @fqn wix.automations.v2.AutomationsService.CreateAutomation
 */
export declare function createAutomation(automation: Automation, options?: CreateAutomationOptions): Promise<Automation & AutomationNonNullableFields>;
export interface CreateAutomationOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Retrieves an automation.
 * @param automationId - Automation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns The requested automation.
 * @fqn wix.automations.v2.AutomationsService.GetAutomation
 */
export declare function getAutomation(automationId: string, options?: GetAutomationOptions): Promise<Automation & AutomationNonNullableFields>;
export interface GetAutomationOptions {
    /** Automation origin. */
    origin?: Origin;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Updates an automation.
 *
 * Each time the automation is updated,
 * `revision` increments by 1.
 * The current `revision` must be passed when updating the automation.
 * This ensures you're working with the latest automation
 * and prevents unintended overwrites.
 * @param _id - Automation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField automation
 * @requiredField automation.revision
 * @permissionId AUTOMATIONS.AUTOMATION_UPDATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Updated automation.
 * @fqn wix.automations.v2.AutomationsService.UpdateAutomation
 */
export declare function updateAutomation(_id: string | null, automation: UpdateAutomation, options?: UpdateAutomationOptions): Promise<Automation & AutomationNonNullableFields>;
export interface UpdateAutomation {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the automation is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the automation.
     *
     * Ignored when creating an automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Information about the creator of the automation.
     * @immutable
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * Date and time the automation was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The entity that last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * Date and time the automation was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Automation name that is displayed on the user's site.
     * @minLength 1
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description.
     * @maxLength 2000
     */
    description?: string | null;
    /** Object that defines the automation's trigger, actions, and activation status. */
    configuration?: AutomationConfiguration;
    /**
     * Defines how the automation was added to the site.
     * @immutable
     */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * Draft info (optional - only if the automation is a draft)
     * @readonly
     */
    draftInfo?: DraftInfo;
    /**
     * Namespace
     * @maxLength 50
     */
    namespace?: string | null;
    /** Extended Fields */
    extendedFields?: ExtendedFields;
}
export interface UpdateAutomationOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Deletes an Automation.
 * @param automationId - Automation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_DELETE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.DeleteAutomation
 */
export declare function deleteAutomation(automationId: string): Promise<void>;
/**
 * Deletes multiple automations.
 * @param automationIds - Automation IDs to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField automationIds
 * @permissionId AUTOMATIONS.AUTOMATION_DELETE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.BulkDeleteAutomations
 */
export declare function bulkDeleteAutomations(automationIds: string[]): Promise<BulkDeleteAutomationsResponse & BulkDeleteAutomationsResponseNonNullableFields>;
/**
 * We have a special identification mechanism here with Dev Center.
 * @param automation - Preinstalled automation to be created.
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @requiredField automation.configuration
 * @requiredField automation.configuration.actions
 * @requiredField automation.configuration.rootActionIds
 * @requiredField automation.configuration.status
 * @requiredField automation.configuration.trigger
 * @requiredField automation.configuration.trigger.appId
 * @requiredField automation.configuration.trigger.triggerKey
 * @requiredField automation.name
 * @fqn wix.automations.v2.AutomationsService.CreatePreinstalledAutomation
 */
export declare function createPreinstalledAutomation(automation: Automation, options?: CreatePreinstalledAutomationOptions): Promise<CreatePreinstalledAutomationResponse & CreatePreinstalledAutomationResponseNonNullableFields>;
export interface CreatePreinstalledAutomationOptions {
    /** Optional - hide the created automation behind a spec */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * Optional - the information about the original site automation that was used to create this preinstalled automation
     * Usually an existing automation in a site is used to create the preinstalled automation, this is the relevant information.
     */
    originAutomationInfo?: OriginAutomationInfo;
    /**
     * The app id for which the automation belongs
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * We have a special identification mechanism here with Dev Center.
 * @param automation - Preinstalled automation to update.
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @requiredField automation.originInfo.preinstalledInfo
 * @requiredField automation.originInfo.preinstalledInfo.componentId
 * @requiredField automation.originInfo.preinstalledInfo.componentVersion
 * @fqn wix.automations.v2.AutomationsService.UpdatePreinstalledAutomation
 */
export declare function updatePreinstalledAutomation(automation: Automation, options?: UpdatePreinstalledAutomationOptions): Promise<UpdatePreinstalledAutomationResponse & UpdatePreinstalledAutomationResponseNonNullableFields>;
export interface UpdatePreinstalledAutomationOptions {
    /** Optional - hide the updated automation behind a spec */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * The app id for which the automation belongs
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * We have a special identification mechanism here with Dev Center.
 * @param componentId - Preinstalled Component Id
 * @public
 * @documentationMaturity preview
 * @requiredField componentId
 * @fqn wix.automations.v2.AutomationsService.DeletePreinstalledAutomation
 */
export declare function deletePreinstalledAutomation(componentId: string, options?: DeletePreinstalledAutomationOptions): Promise<void>;
export interface DeletePreinstalledAutomationOptions {
    /**
     * Optional - makes the deletion operation gradual
     * The automation will not return if the variant returns for the site
     */
    specInfo?: PreinstalledAutomationSpecInfo;
    /**
     * The app id for which the component of the preinstalled belongs
     * @format GUID
     */
    appId?: string;
}
/**
 * We have a special identification mechanism here with Dev Center.
 * @public
 * @documentationMaturity preview
 * @fqn wix.automations.v2.AutomationsService.QueryPreinstalledAutomationsForApp
 */
export declare function queryPreinstalledAutomationsForApp(options?: QueryPreinstalledAutomationsForAppOptions): Promise<QueryPreinstalledAutomationsForAppResponse & QueryPreinstalledAutomationsForAppResponseNonNullableFields>;
export interface QueryPreinstalledAutomationsForAppOptions {
    /** WQL expression. */
    query?: CursorQuery;
    /**
     * The app id which the query is requested for
     * @format GUID
     */
    appId?: string;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Retrieves a list of automations. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 * @public
 * @documentationMaturity preview
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.QueryAutomations
 */
export declare function queryAutomations(options?: QueryAutomationsOptions): AutomationsQueryBuilder;
export interface QueryAutomationsOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[] | undefined;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
export interface AutomationsQueryResult extends QueryCursorResult {
    items: Automation[];
    query: AutomationsQueryBuilder;
    next: () => Promise<AutomationsQueryResult>;
    prev: () => Promise<AutomationsQueryResult>;
}
export interface AutomationsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: 'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: 'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition', value: any) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: 'name' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey', value: string) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: 'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition', value: any[]) => AutomationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasAll: (propertyName: 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds', value: any[]) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: 'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition', value: any) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: 'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition', value: boolean) => AutomationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filters' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition'>) => AutomationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'name' | 'configuration.status' | 'configuration.trigger.appId' | 'configuration.trigger.triggerKey' | 'configuration.trigger.filters' | 'configuration.trigger.filterValueSelection.selectedFilterValues' | 'origin' | 'settings' | 'settings.readonly' | 'settings.disableDelete' | 'settings.disableStatusChange' | 'settings.actionSettings' | 'settings.actionSettings.permanentActionIds' | 'settings.actionSettings.readonlyActionIds' | 'settings.actionSettings.disableDelayAddition' | 'settings.actionSettings.disableConditionAddition'>) => AutomationsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => AutomationsQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => AutomationsQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<AutomationsQueryResult>;
}
/**
 * Creates a copy of an action with a new ID, and changes the action's input mapping if necessary.
 *
 * The action copy isn't saved automatically. To save it, the user must perform an action
 * such as clicking the **Save** button.
 * @param automationId - Automation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_COPY
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.CopyAutomation
 */
export declare function copyAutomation(automationId: string, options?: CopyAutomationOptions): Promise<CopyAutomationResponse & CopyAutomationResponseNonNullableFields>;
export interface CopyAutomationOptions {
    /** Automation origin. */
    origin?: Origin;
    /** (optional) Automation to copy, skips fetch by id. */
    automation?: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Creates a draft automation.
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.AUTOMATION_DRAFT_CREATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.CreateDraftAutomation
 */
export declare function createDraftAutomation(options?: CreateDraftAutomationOptions): Promise<CreateDraftAutomationResponse & CreateDraftAutomationResponseNonNullableFields>;
export interface CreateDraftAutomationOptions {
    /** Draft automation to be created. */
    automation?: Automation;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Gets the draft of the given original automation if exists, or creates one and returns it
 *
 * - if the original automation is a draft, returns the original automation
 * @param originalAutomationId - Original automation id
 * @public
 * @documentationMaturity preview
 * @requiredField originalAutomationId
 * @permissionId AUTOMATIONS.AUTOMATION_DRAFT_CREATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.GetOrCreateDraftAutomation
 */
export declare function getOrCreateDraftAutomation(originalAutomationId: string, options?: GetOrCreateDraftAutomationOptions): Promise<GetOrCreateDraftAutomationResponse & GetOrCreateDraftAutomationResponseNonNullableFields>;
export interface GetOrCreateDraftAutomationOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Updates a draft automation
 * @param _id - Automation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField automation
 * @permissionId AUTOMATIONS.AUTOMATION_DRAFT_UPDATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.UpdateDraftAutomation
 */
export declare function updateDraftAutomation(_id: string | null, automation: UpdateDraftAutomation, options?: UpdateDraftAutomationOptions): Promise<UpdateDraftAutomationResponse & UpdateDraftAutomationResponseNonNullableFields>;
export interface UpdateDraftAutomation {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the automation is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the automation.
     *
     * Ignored when creating an automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Information about the creator of the automation.
     * @immutable
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * Date and time the automation was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The entity that last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * Date and time the automation was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Automation name that is displayed on the user's site.
     * @minLength 1
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description.
     * @maxLength 2000
     */
    description?: string | null;
    /** Object that defines the automation's trigger, actions, and activation status. */
    configuration?: AutomationConfiguration;
    /**
     * Defines how the automation was added to the site.
     * @immutable
     */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * Draft info (optional - only if the automation is a draft)
     * @readonly
     */
    draftInfo?: DraftInfo;
    /**
     * Namespace
     * @maxLength 50
     */
    namespace?: string | null;
    /** Extended Fields */
    extendedFields?: ExtendedFields;
}
export interface UpdateDraftAutomationOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Retrieves a list of automations including drafts. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * - new drafts that are not related to existing automations will be returned in the list
 * - the response will contain a map of originalAutomationId => relatedDrafts
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.AUTOMATION_DRAFT_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.QueryAutomationsWithDrafts
 */
export declare function queryAutomationsWithDrafts(options?: QueryAutomationsWithDraftsOptions): Promise<QueryAutomationsWithDraftsResponse & QueryAutomationsWithDraftsResponseNonNullableFields>;
export interface QueryAutomationsWithDraftsOptions {
    /** WQL expression. */
    query?: CursorQuery;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Deletes a draft automation.
 * @param automationId - Id of the draft automation to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_DRAFT_DELETE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.DeleteDraftAutomation
 */
export declare function deleteDraftAutomation(automationId: string): Promise<void>;
/**
 * Publishes a draft automation, applying the changes to live automation
 * @param automationId - Id of the draft automation to publish.
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_UPDATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.PublishDraftAutomation
 */
export declare function publishDraftAutomation(automationId: string, options?: PublishDraftAutomationOptions): Promise<PublishDraftAutomationResponse & PublishDraftAutomationResponseNonNullableFields>;
export interface PublishDraftAutomationOptions {
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
/**
 * Validates the automation without requiring the automation ID to be passed in.
 * @param automation - Automation to validate.
 * @public
 * @documentationMaturity preview
 * @requiredField automation
 * @permissionId AUTOMATIONS.AUTOMATION_VALIDATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.ValidateAutomation
 */
export declare function validateAutomation(automation: Automation, options?: ValidateAutomationOptions): Promise<ValidateAutomationResponse & ValidateAutomationResponseNonNullableFields>;
export interface ValidateAutomationOptions {
    /** Settings to customize the validation. */
    validationSettings?: ValidationSettings;
}
/**
 * Validate Automation by automation ID
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.AUTOMATION_VALIDATE
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.ValidateAutomationById
 */
export declare function validateAutomationById(automationId: string, options?: ValidateAutomationByIdOptions): Promise<ValidateAutomationByIdResponse & ValidateAutomationByIdResponseNonNullableFields>;
export interface ValidateAutomationByIdOptions {
    /** Settings to customize the validation. */
    validationSettings?: ValidationSettings;
}
/**
 * Gets the payload schema received by the action whose ID is passed in.
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.actionId
 * @requiredField identifiers.automationId
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.GetAutomationActionSchema
 */
export declare function getAutomationActionSchema(identifiers: GetAutomationActionSchemaIdentifiers): Promise<GetAutomationActionSchemaResponse>;
export interface GetAutomationActionSchemaIdentifiers {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /**
     * Action ID
     * @format GUID
     */
    actionId: string;
}
/**
 * Gets action quota information.
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.AUTOMATION_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.v2.AutomationsService.GetActionsQuotaInfo
 */
export declare function getActionsQuotaInfo(): Promise<GetActionsQuotaInfoResponse & GetActionsQuotaInfoResponseNonNullableFields>;
export interface GetAutomationRevisionOptions {
    /** Automation revision. */
    revision?: string | null;
    /**
     * Requested fields
     * @maxSize 20
     */
    fields?: RequestedFields[];
}
export {};
